<?php

// This extension defines the <gid> tag to expand global IDs to include a screen name.
// Usage: <gid server="armagetronad-server-name">name</gid>

// Configuration variables

$wgGIDConfigSite = "http://gridstats.com";
// $wgGIDConfigSite = "http://localhost:9292";

$wgExtensionCredits["validextensionclass"][] = array(
    "name" => "GID",
    "author" =>"dlh",
    "url" => "http://wiki.armagetronad.net/index.php?title=GIDTag",
    "description" => "Expands Armagetron Advanced Global IDs to include a screen name."
);

$wgHooks['ParserFirstCallInit'][] = 'dlhGIDParserInit';

function dlhGIDParserInit(&$parser) {
    $parser->setHook('gid', 'dlhGIDRender');
    return true;
}

function dlhGIDRender($input, $args, $parser, $frame) {
    global $wgGIDConfigSite;
    $names = $parser->recursiveTagParse($input, $frame);
    
    // Ensure the tag options are valid
    if ((!isset($args["server"]) || empty($args["server"])) || empty($names)) {
        // Invalid options, just return what the user requested
        return dlhEscapeHTML($names);
    }
    
    // Fetch the name
    return dlhEscapeHTML(dlhDisplayName($wgGIDConfigSite, $args["server"], $names, false));
}

function dlhEscapeHTML($text) {
    return htmlspecialchars($text, ENT_COMPAT, "UTF-8");
}

// Fetches the display name for a player
function dlhDisplayName($site, $server, $names, $short_name) {
    $url = $site . "/" . urlencode($server) . "/display-name?names=" . urlencode($names);
    if ($short_name) {
        $url .= "&short_name=1";
    }
    $display_names = @file_get_contents($url);
    
    // Error handling
    if ($display_names === FALSE || empty($display_names)) {
        return $names;
    }
    
    return $display_names;
}

// MIT License
// 
// Copyright (c) 2010 DLH
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

?>
